@@ -10,6 +10,7 @@ def casing():
     import math
    # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
     from RocketCasing import materials
+   # import materials
     from datetime import datetime
 
 #Abertura do programa
@@ -52,28 +53,28 @@ def casing():
     if op=="0":
         print(" ")
         print ("---Pressões de design e ruptura---")
-        Pd=(2*(t*p['Fty']*1000)/(Do*Sd))#*6.8947
+        Pd=(2*(t*p['Fty']*1000)/(Do*Sd)) if Do!=0 or Sd!=0 else 0
         print("Design de pressão: Pd= ",'{:.5f}'.format(Pd)," kPa")
-        Pu=(2*B*t*p['Fty']*1000/Do)#*6.8947
+        Pu=(2*B*t*p['Fty']*1000/Do) if Do!=0 else 0
         print("Pressão de ruptura: Pu= ",'{:.5f}'.format(Pu), " kPa")
-        Su=Pu/Pd
+        Su=Pu/Pd if Pd!=0 else 0
         print("Fator de segurança de ruptura: Su= ",'{:.5f}'.format(Su))
     elif op=="1":
         print(" ")
         print ("---Pressões de design e ruptura---")
-        Pu=(2*B*t*p['Fty']*1000/Do)#*6.8947
+        Pu=(2*B*t*p['Fty']*1000/Do) if Do!=0 else 0
         print("Pressão de ruptura: Pu= ",'{:.5f}'.format(Pu), " kPa")
-        Pd=Pu/Su
+        Pd=Pu/Su if Su!=0 else 0
         print("Design de pressão: Pd= ",'{:.5f}'.format(Pd)," kPa")
-        Sd=(2*(t*p['Fty']*1000)/(Do*Pd))
+        Sd=(2*(t*p['Fty']*1000)/(Do*Pd)) if Do!=0 or Sd!=0 else 0
         print("Fator de design de segurança: Sd= ",'{:.5f}'.format(Sd))
     
     print (" ")
     print(" ")
     print ("---Deformação elástica sobre pressão---")
-    dD=(2*Pd*(Do/2)**2/p['E']/10**6/t*(1-p['v']/2))#*0.0254
+    dD=(2*Pd*(Do/2)**2/p['E']/10**6/t*(1-p['v']/2)) if p['E']!=0 or p['v']!=0 else 0
     print("Variação do diâmetro do invólucro: dD= ",'{:.6f}'.format(dD)," m")
-    dc=((dD*math.pi))#*0.0254
+    dc=((dD*math.pi))
     print("Variação da circunferência do invólucro: dc= ",'{:.6f}'.format(dc)," m")
 
 #Construção gráfico (de acordo com a planilha do Nakka)
@@ -85,6 +86,7 @@ def casing():
     matplotlib.pyplot.axis([0.5, 1, 1, 2.2]) # [xmin, xmax, ymin, ymax]
     matplotlib.pyplot.show()
     '''
+    #o gráfico apresenta uma curva para o fator de explosão para cilindros pressurizados. Uma curva fixa que apresenta os melhores valores.
  
 #construção do arquivo em txt com os valores
     data=datetime.now()
@@ -131,4 +133,6 @@ def casing():
     arquivo.write(' ')
     arquivo.close()
 
-casing()
\ No newline at end of file
+
+casing()
+
