@@ -1,3 +1,3 @@
 from RocketCasing import RocketCasing
 
-RocketCasing.case()
+RocketCasing.casing()
